/****************************************************************************
** Meta object code from reading C++ file 'consolemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalgebra-26.08.0/src/consolemodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'consolemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ConsoleModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ConsoleModel::qt_create_metaobjectdata<qt_meta_tag_ZN12ConsoleModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ConsoleModel",
        "message",
        "",
        "msg",
        "Analitza::Expression",
        "operation",
        "result",
        "updateView",
        "modeChanged",
        "ConsoleModel::ConsoleMode",
        "mode",
        "operationSuccessful",
        "expression",
        "variablesChanged",
        "addOperation",
        "input",
        "loadScript",
        "QUrl",
        "path",
        "saveScript",
        "clear",
        "saveLog",
        "readContent",
        "url",
        "ConsoleMode",
        "variables",
        "QSharedPointer<Analitza::Variables>",
        "Evaluation",
        "Calculation"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'message'
        QtMocHelpers::SignalData<void(const QString &, const Analitza::Expression &, const Analitza::Expression &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 },
        }}),
        // Signal 'updateView'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void(ConsoleModel::ConsoleMode)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'operationSuccessful'
        QtMocHelpers::SignalData<void(const Analitza::Expression &, const Analitza::Expression &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 12 }, { 0x80000000 | 4, 6 },
        }}),
        // Signal 'variablesChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'addOperation'
        QtMocHelpers::MethodData<bool(const QString &)>(14, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 15 },
        }}),
        // Method 'loadScript'
        QtMocHelpers::MethodData<bool(const QUrl &)>(16, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'saveScript'
        QtMocHelpers::MethodData<bool(const QUrl &)>(19, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(20, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'saveLog'
        QtMocHelpers::MethodData<bool(const QUrl &) const>(21, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'readContent'
        QtMocHelpers::MethodData<QString(const QUrl &)>(22, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { 0x80000000 | 17, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mode'
        QtMocHelpers::PropertyData<enum ConsoleMode>(10, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'variables'
        QtMocHelpers::PropertyData<QSharedPointer<Analitza::Variables>>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ConsoleMode'
        QtMocHelpers::EnumData<enum ConsoleMode>(24, 24, QMC::EnumFlags{}).add({
            {   27, ConsoleMode::Evaluation },
            {   28, ConsoleMode::Calculation },
        }),
    };
    return QtMocHelpers::metaObjectData<ConsoleModel, qt_meta_tag_ZN12ConsoleModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ConsoleModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ConsoleModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ConsoleModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ConsoleModelE_t>.metaTypes,
    nullptr
} };

void ConsoleModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConsoleModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->message((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Analitza::Expression>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Analitza::Expression>>(_a[3]))); break;
        case 1: _t->updateView(); break;
        case 2: _t->modeChanged((*reinterpret_cast<std::add_pointer_t<ConsoleModel::ConsoleMode>>(_a[1]))); break;
        case 3: _t->operationSuccessful((*reinterpret_cast<std::add_pointer_t<Analitza::Expression>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Analitza::Expression>>(_a[2]))); break;
        case 4: _t->variablesChanged(); break;
        case 5: { bool _r = _t->addOperation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->loadScript((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->saveScript((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->clear(); break;
        case 9: { bool _r = _t->saveLog((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->readContent((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Analitza::Expression >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Analitza::Expression >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ConsoleModel::*)(const QString & , const Analitza::Expression & , const Analitza::Expression & )>(_a, &ConsoleModel::message, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConsoleModel::*)()>(_a, &ConsoleModel::updateView, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConsoleModel::*)(ConsoleModel::ConsoleMode )>(_a, &ConsoleModel::modeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConsoleModel::*)(const Analitza::Expression & , const Analitza::Expression & )>(_a, &ConsoleModel::operationSuccessful, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConsoleModel::*)()>(_a, &ConsoleModel::variablesChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum ConsoleMode*>(_v) = _t->mode(); break;
        case 1: *reinterpret_cast<QSharedPointer<Analitza::Variables>*>(_v) = _t->variables(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMode(*reinterpret_cast<enum ConsoleMode*>(_v)); break;
        case 1: _t->setVariables(*reinterpret_cast<QSharedPointer<Analitza::Variables>*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ConsoleModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConsoleModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ConsoleModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ConsoleModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ConsoleModel::message(const QString & _t1, const Analitza::Expression & _t2, const Analitza::Expression & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void ConsoleModel::updateView()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ConsoleModel::modeChanged(ConsoleModel::ConsoleMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ConsoleModel::operationSuccessful(const Analitza::Expression & _t1, const Analitza::Expression & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void ConsoleModel::variablesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
